##  Installation of LeanIX Integration App
To get the communication between SAP LeanIX and ServiceNow running, the SAP LeanIX Integration app is required which is available in ServiceNow Store.
ServiceNow Instance administrators can request installation of the app while logged on to the store.
App | Link
---|---
SAP LeanIX Integration Required |  [Link to the Application![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.servicenow.com%2Fsn_appstore_store.do%23%21%2Fstore%2Fapplication%2F849f6f03db864b00bac3d8c0cf9619d3 "https://store.servicenow.com/sn_appstore_store.do#!/store/application/849f6f03db864b00bac3d8c0cf9619d3")
SAP LeanIX Integration SAM add-on Optional |  [Link to the Add-on![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fstore.servicenow.com%2Fsn_appstore_store.do%23%21%2Fstore%2Fapplication%2F27430063db3a1b00bac3d8c0cf961952 "https://store.servicenow.com/sn_appstore_store.do#!/store/application/27430063db3a1b00bac3d8c0cf961952")


![3496](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d3c5c7a44101487c0eade4573cd56_LowRes.png)
Request the application
